#ifndef NT2_INCLUDE_FUNCTIONS_SCALAR_GAMMAINC_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_SCALAR_GAMMAINC_HPP_INCLUDED

#include <nt2/euler/include/functions/scalar/gammainc.hpp>

#endif
